.. include:: substitutions.rst

.. _linux-page:

*******************************************
Linux distributions used for the containers
*******************************************

Geniac can build containers using several Linux distributions which have been made available on the |4geniac|_ docker hub repositories including:

* |almalinux|_ with the versions available at |4geniacalmalinux|_
* |centos|_ with the versions available at |4geniaccentos|_
* |rockylinux|_ with the versions available at |4geniacrockylinux|_


The Linux distribution can be set using the :ref:`install-ap_linux_distro` during the configuration step with |cmake|_.

